@@ -246,7 +246,7 @@ notetiff(const char *name)
 		break;
 	    case 279:		/* StripByteCounts */
 		if (count != nstrips) {
-		  str.sprintf("In file %s\nStrpisPerImage tag 273=%ls,tag279=%ld\n",
+		  str.sprintf("In file %s\nStrpisPerImage tag 273=%ld,tag279=%ld\n",
 			      name, nstrips,(long int) count);
 		  kfaxerror("Message",str);
 		  goto realbad;
