@@ -12,7 +12,6 @@
 #include <qpaintdevice.h>
 #include <qpoint.h>
 #include <qqueue.h>
-#include <qscrollview.h>
 #include <qbitmap.h>
 #include <qsocketnotifier.h>
 #define	 GC GC_QQQ				// avoid type mismatch
@@ -22,9 +21,9 @@
 #include <X11/Xatom.h>
 #include <ctype.h>
 
-#include "kdsc.h"
+#include "kgv.h"
 #include "messages.h"
-class InterpreterDialog;
+class KGVConfigDialog;
 
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -65,7 +64,6 @@ public:
     KPSWidget( QWidget *parent = 0, const char* name = 0 );
     ~KPSWidget();
 
-    
     void enableInterpreter();
     void disableInterpreter();
     
@@ -73,30 +71,26 @@ public:
     bool isInterpreterRunning() const;
     
     bool nextPage();
-    bool sendPS( FILE* fp, const KDSC::Offset&, bool close);
+    bool sendPS( FILE* fp, const KGV::FileOffset&, bool close);
     
     void setFileName( const QString& );
 
+    void setPageSize( const QSize& );
+    QSize pageSize() const { return _pageSize; }
     
-    void layout();
-    void relayout();
-    void setDelayedLayout( bool );
+    void setBoundingBox( const KGV::BoundingBox& );
+    KGV::BoundingBox boundingBox() const { return _boundingBox; }
     
-    void setBoundingBox( const KDSC::BoundingBox& );
-    KDSC::BoundingBox boundingBox() const { return _boundingBox; }
-    
-    void setOrientation( int orientation );
+    void setOrientation( KGV::Orientation orientation );
     int orientation() const { return _orientation; }
     
     void setResolution( int xdpi, int ydpi);
     
+    void layout();
     
     bool configure();
     void writeSettings();
 	
-signals:
-    void pageSizeChanged( QSize );
-
 protected:    
     struct Record {
 	~Record() { if( close ) fclose( fp ); }
@@ -106,11 +100,11 @@ protected:
 	bool seek_needed;
 	bool close;
     };
-	
+    
+    // void resizeEvent( QResizeEvent* );
     bool x11Event( XEvent* );
     
     void setup();
-    bool computeSize();
     
     void startInterpreter();
     void stopInterpreter();
@@ -125,77 +119,43 @@ private:
     
     Display*	gs_display;
     Window	gs_window;
-    
-    Atom gs_colors, ghostview, gs_next, gs_page, gs_done;
+   
+    Atom ghostview; 
+    Atom ghostview_colors;
+    Atom next;
+    Atom page;
+    Atom done;
     
     /**
      * Variables used to communicate with the gs process.
      */
-    Pixmap  background_pixmap;
-    int	    orient_angle;
-    KDSC::BoundingBox _boundingBox;
+    Pixmap		_backgroundPixmap;
+    QSize		_pageSize;
+    KGV::BoundingBox	_boundingBox;
     float   _xdpi, _ydpi;
     int	    left_margin, right_margin, bottom_margin, top_margin;
+
+    int _baseXdpi, _baseYdpi;
     
     MessagesDialog*	messages;
-    InterpreterDialog*	intConfig;
+    KGVConfigDialog*	intConfig;
 
-    KProcess*	    proc;
+    KProcess* _process;
  
     QQueue<Record>  _inputQueue;
     char*	    input_buffer;
     unsigned int    bytes_left;
-    bool	    stdin_ready;
     
-    bool busy;
-    int _orientation;
-    bool antialias;
+    KGV::Orientation _orientation;
     bool show_messages;
     QString _fileName;
-    int foreground, background_pixel;
 
-    // Some flags
+    bool _stdinReady;
+    bool _interpreterBusy;
     bool _interpreterReady;
-    bool _disableStart;	    // Disables starting the interpreter.
-    bool _delayedLayout;    
+    bool _interpreterDisabled; // Disables starting the interpreter.
     bool _layoutDirty;
 };
 
-class KPSView : public QScrollView
-{
-    Q_OBJECT
-
-public:
-    KPSView( QWidget* parent = 0, const char* name = 0 );
-    ~KPSView() { ; }
-
-    KPSWidget* psWidget() const { return _psWidget; }
-
-    void enableScrollBars( bool);
-    
-    bool eventFilter( QObject*, QEvent* );
-    
-public slots:
-    bool readDown();
-    void scrollUp();
-    void scrollDown();
-    void scrollRight();
-    void scrollLeft();
-    void scrollTop();
-   
-signals:
-    void viewSizeChanged( QSize size );
-    
-protected:
-    void keyPressEvent( QKeyEvent* );
-    void viewportResizeEvent( QResizeEvent* );
-    void centerContents();
-    
-private:
-    QPoint _dragGrabPos;
-    
-    KPSWidget* _psWidget;
-};
-
 #endif // KPSWIDGET_H
 
