@@ -23,9 +23,11 @@ public slots:
 	void	setPageSize( QSize );
 	void	setViewSize( QSize );
 	void	setViewPos( QPoint );
+	void	setViewPos( int x, int y ) { setViewPos( QPoint( x, y ) ); }
 
 signals:
 	void	valueChanged( QPoint );
+	void    valueChangedRelative( int dx, int dy );
 	void	button2Pressed(); 
 	void	button3Pressed(); 
 
