@@ -40,7 +40,7 @@
 #include "config.h"
 #endif
 
-#if HAVE_FCNTL_H && !HAVE_FLOCK
+#if defined(HAVE_FCNTL_H) && !defined(HAVE_FLOCK)
 #include <fcntl.h>
 #endif
 
