@@ -50,13 +50,13 @@ public:
   KTemplateEditDlg(QWidget *);
   ~KTemplateEditDlg() {};
 
-  const char *getName();
-  const char *getPath();
-  void setName(QString);
-  void setPath(QString);
+  QString getName();
+  QString getPath();
+  void setName(const QString &);
+  void setPath(const QString &);
   
 public slots:
-  void slotTextChanged(const char*);
+  void slotTextChanged(const QString &);
   void slotBrowse();
 
 protected:
