@@ -53,11 +53,9 @@ void KIconEdit::init()
 {
   setCaption(kapp->caption());
 
-  printer = new QPrinter;
-  CHECK_PTR(printer);
+  printer = new KPrinter;
 
   kiprops = new KIconEditProperties(this);
-  CHECK_PTR(kiprops);
   Properties *pprops = props(this);
 
   menubar = 0L;
@@ -68,14 +66,11 @@ void KIconEdit::init()
   what = 0L;
 
   msgtimer = new QTimer(this);
-  CHECK_PTR(msgtimer);
   connect( msgtimer, SIGNAL(timeout()), SLOT(slotClearStatusMessage()));
 
   icontemplates = new KIconTemplateContainer;
-  CHECK_PTR(icontemplates);
 
   gridview = new KGridView(&img, this); 
-  CHECK_PTR(gridview);
   gridview->setShowRulers(pprops->showrulers);
 
   grid = gridview->grid();
@@ -84,7 +79,6 @@ void KIconEdit::init()
   grid->setCellSize(pprops->gridscaling);
 
   icon = new KIconEditIcon(this, &grid->image());
-  CHECK_PTR(icon);
 
   setAcceptDrops(true);
 
@@ -170,35 +164,9 @@ KIconEdit::~KIconEdit()
       delete what;
     what = 0L;
 
-    if(toolbar)
-      delete toolbar;
-    toolbar = 0L; 
-
-    if(drawtoolbar)
-      delete drawtoolbar;
-    drawtoolbar = 0L; 
-
-    if(menubar)
-      delete menubar;
-    menubar = 0L; 
-
-    if(statusbar)
-      delete statusbar;
-    statusbar = 0L; 
-
     if(icontemplates)
       delete icontemplates;
     icontemplates = 0L;
-
-    delete file;
-    delete edit;
-    delete view;
-    delete tools;
-    delete options;
-    delete help;
-    delete select;
-    delete recent;
-    delete zoom;
 }
 
 bool KIconEdit::queryClose()
@@ -234,9 +202,9 @@ bool KIconEdit::queryClose()
 /* 
     save size of the application window
 */
-void KIconEdit::resizeEvent( QResizeEvent * )
+void KIconEdit::resizeEvent( QResizeEvent *ev )
 {
-
+  KMainWindow::resizeEvent(ev);
   //kdDebug() << "KIconEdit::resizeEvent()" << endl;
   
   props(this)->winwidth = geometry().width();
@@ -290,16 +258,10 @@ bool KIconEdit::setupMenuBar()
   kdDebug() << "setupMenuBar" << endl;
 
   Properties *pprops = props(this);
-
-  if(!menubar)
-  {
-    menubar = new KMenuBar(this);
-    CHECK_PTR(menubar);
-    pprops->menubar = menubar;
-  }
+  menubar = menuBar();
+  pprops->menubar = menubar;
 
   KAccel *keys = pprops->keys; 
-  CHECK_PTR(keys);
 
   keys->connectItem( KStdAccel::New, this, SLOT(slotNew()) );
   keys->connectItem( KStdAccel::Save , this, SLOT(slotSave()) );
@@ -316,8 +278,7 @@ bool KIconEdit::setupMenuBar()
 
   kdDebug() << "setupMenuBar - read settings" << endl;
 
-  recent = new QPopupMenu;
-  CHECK_PTR(recent);
+  recent = new QPopupMenu(menubar);
   connect( recent, SIGNAL(activated(int)), SLOT(slotOpenRecent(int)));
 
   for ( QStringList::Iterator it = pprops->recentlist->begin();
@@ -326,8 +287,7 @@ bool KIconEdit::setupMenuBar()
 
   int id;
 
-  file = new QPopupMenu;
-  CHECK_PTR(file);
+  file = new QPopupMenu(menubar);
 
   file->insertItem(SmallIcon("newwin"), i18n("New &Window"), ID_FILE_NEWWIN);
   file->connectItem(ID_FILE_NEWWIN, this, SLOT(slotNewWin()));
@@ -362,8 +322,7 @@ bool KIconEdit::setupMenuBar()
 
   menubar->insertItem(i18n("&File"), file);
 
-  edit = new QPopupMenu;
-  CHECK_PTR(edit);
+  edit = new QPopupMenu(menubar);
 
   id = edit->insertItem(SmallIcon("editcut"), i18n("Cu&t"), ID_EDIT_CUT);
   edit->connectItem(ID_EDIT_CUT, this, SLOT(slotCut()));
@@ -386,23 +345,20 @@ bool KIconEdit::setupMenuBar()
 
   menubar->insertItem(i18n("&Edit"), edit);
 
-  zoom = new QPopupMenu;
-  CHECK_PTR(zoom);
+  zoom = new QPopupMenu(menubar);
   id = zoom->insertItem(i18n("1:1"), ID_VIEW_ZOOM_1TO1);
   id = zoom->insertItem(i18n("1:5"), ID_VIEW_ZOOM_1TO5);
   id = zoom->insertItem(i18n("1:10"), ID_VIEW_ZOOM_1TO10);
   connect( zoom, SIGNAL(activated(int)), SLOT(slotView(int)));
 
-  view = new QPopupMenu;
-  CHECK_PTR(view);
+  view = new QPopupMenu(menubar);
   id = view->insertItem(SmallIcon("viewmag+"), i18n("Zoom &in"), ID_VIEW_ZOOM_IN);
   id = view->insertItem(SmallIcon("viewmag-"), i18n("Zoom &out"), ID_VIEW_ZOOM_OUT);
   id = view->insertItem(SmallIcon("viewmag"), i18n("Zoom factor"), zoom);
   connect( view, SIGNAL(activated(int)), SLOT(slotView(int)));
   menubar->insertItem(i18n("&View"), view);
 
-  image = new QPopupMenu;
-  CHECK_PTR(image);
+  image = new QPopupMenu(menubar);
 
   id = image->insertItem(SmallIcon("transform"), i18n("&Resize"), ID_IMAGE_RESIZE);
   id = image->insertItem(SmallIcon("grayscale"), i18n("&GrayScale"), ID_IMAGE_GRAYSCALE);
@@ -412,8 +368,7 @@ bool KIconEdit::setupMenuBar()
   connect( image, SIGNAL(activated(int)), SLOT(slotImage(int)));
   menubar->insertItem(i18n("&Icon"), image);
 
-  tools = new QPopupMenu;
-  CHECK_PTR(tools);
+  tools = new QPopupMenu(menubar);
   tools->insertItem(SmallIcon("paintbrush"), i18n("Freehand"), ID_DRAW_FREEHAND);
   tools->insertItem(SmallIcon("rectangle"), i18n("Rectangle"), ID_DRAW_RECT);
   tools->insertItem(SmallIcon("filledrectangle"), i18n("Filled rectangle"), ID_DRAW_RECT_FILL);
@@ -430,8 +385,7 @@ bool KIconEdit::setupMenuBar()
   connect( tools, SIGNAL(activated(int)), SLOT(slotTools(int)));
   menubar->insertItem(i18n("&Tools"), tools);
 
-  options = new QPopupMenu;
-  CHECK_PTR(options);
+  options = new QPopupMenu(menubar);
   id = options->insertItem(i18n("&Configure"), ID_OPTIONS_CONFIGURE);
   options->insertSeparator();
   options->insertItem(i18n("Show &Grid"), ID_OPTIONS_TOGGLE_GRID);
@@ -468,7 +422,6 @@ bool KIconEdit::setupMenuBar()
 void KIconEdit::updateMenuAccel()
 {
   KAccel *keys = props(this)->keys;  
-  CHECK_PTR(keys);
 
   keys->changeMenuAccel(file, ID_FILE_NEWFILE, KStdAccel::New); 
   keys->changeMenuAccel(file, ID_FILE_OPEN, KStdAccel::Open); 
@@ -490,7 +443,6 @@ bool KIconEdit::setupToolBar()
   kdDebug() << "setupToolBar" << endl;
 
   toolbar = toolBar();
-  CHECK_PTR(toolbar);
   pprops->maintoolbar = toolbar;
 
   QWidget *btwhat = (QWidget*)what->whatsThisButton(toolbar);
@@ -514,8 +466,7 @@ bool KIconEdit::setupToolBar()
   toolbar->insertButton(BarIcon("editpaste"),ID_EDIT_PASTE,
          SIGNAL(clicked()), this, SLOT(slotPaste()), TRUE, i18n("Paste"));
 
-  select = new QPopupMenu;
-  CHECK_PTR(select);
+  select = new QPopupMenu(menubar);
   select->insertItem(SmallIcon("selectrect"), ID_SELECT_RECT);
   select->insertItem(SmallIcon("selectcircle"), ID_SELECT_CIRCLE);
   connect( select, SIGNAL(activated(int)), SLOT(slotTools(int)));
@@ -575,7 +526,7 @@ bool KIconEdit::setupDrawToolBar()
 {
   kdDebug() << "setupDrawToolBar" << endl;
   Properties *pprops = props(this);
-  drawtoolbar = new KToolBar(this, "drawToolBar");
+  drawtoolbar = toolBar("drawToolBar");
   pprops->drawtoolbar = drawtoolbar;
   drawtoolbar->setFullSize();
 
@@ -642,9 +593,7 @@ bool KIconEdit::setupPaletteToolBar()
     int iw = syscolors->width();
     int ih = syscolors->height();
 
-    palettetoolbar = new KToolBar(this, 0, ow+8);
-    CHECK_PTR(palettetoolbar);
-    addToolBar(palettetoolbar);
+    palettetoolbar = toolBar("paletteToolbar");
     palettetoolbar->show();
     palettetoolbar->setBarPos(KToolBar::Right);
 
@@ -674,7 +623,6 @@ bool KIconEdit::setupStatusBar()
 {
     Properties *pprops = props(this);
     statusbar = statusBar();
-    CHECK_PTR(statusbar);
     pprops->statusbar = statusbar;
 
     statusbar->insertItem("    -1, -1    ", 0);
@@ -702,11 +650,11 @@ bool KIconEdit::setupWhatsThis()
                  "(Tip: Hold the magnify button down for a few seconds to zoom to a predefined scale");
   what->add(grid, str);
 
-  str = i18n("Rulers\n\nThis is a visual represantation of the current cursor position");
+  str = i18n("Rulers\n\nThis is a visual representation of the current cursor position");
   what->add(gridview->hruler(), str);
   what->add(gridview->vruler(), str);
 
-  str = i18n("Statusbar\n\nThe statusbar gives information of the status "
+  str = i18n("Statusbar\n\nThe statusbar gives information on the status "
              "of the current icon. The fields are:\n\n"
              "\t- Cursor position\n"
              "\t- Size\n"
@@ -723,12 +671,12 @@ bool KIconEdit::setupWhatsThis()
   what->add(syscolors, str);
 
   str = i18n("Custom colors\n\nHere you can build a palette of custom colors.\n"
-             "Just double-click on a box to edit the color");
+             "Double-click on a box to edit the color");
   what->add(customcolors, str);
 
   // Create help for the main toolbar
 
-  str = i18n("New\n\nCreate a new icon either from a template or by specifying the size");
+  str = i18n("New\n\nCreate a new icon, either from a template or by specifying the size");
   what->add(toolbar->getButton(ID_FILE_NEWFILE), str);
 
   str = i18n("Open\n\nOpen an existing icon");
@@ -738,7 +686,7 @@ bool KIconEdit::setupWhatsThis()
   what->add(toolbar->getButton(ID_FILE_SAVE), str);
 
   str = i18n("Print\n\nOpens a print dialog to let you print the current icon."
-             " (Doesn't realy work as expected");
+             " (Doesn't really work as expected");
   what->add(toolbar->getButton(ID_FILE_PRINT), str);
 
   str = i18n("Cut\n\nCut the current selection out of the icon\n\n"
@@ -750,10 +698,10 @@ bool KIconEdit::setupWhatsThis()
   what->add(toolbar->getButton(ID_EDIT_COPY), str);
 
   str = i18n("Paste\n\nPaste the contents of the clipboard into the current icon.\n\n"
-             "If the contents is larger than the current icon you can paste it"
+             "If the contents are larger than the current icon you can paste them"
              " in a new window.\n\n"
              "(Tip: Select \"Paste transparent pixels\" in the configuration dialog"
-             " if you also want to paste transparent)");
+             " if you also want to paste transparency.)");
   what->add(toolbar->getButton(ID_EDIT_PASTE), str);
 
   str = i18n("Select\n\nSelect a section of the icon using the mouse.\n\n"
@@ -807,18 +755,18 @@ bool KIconEdit::setupWhatsThis()
   str = i18n("Filled ellipse\n\nDraw a filled ellipse");
   what->add(drawtoolbar->getButton(ID_DRAW_ELLIPSE_FILL), str);
 
-  str = i18n("Line\n\nDraw a straight line vertically, horizontically or in 45 dgr. angles");
+  str = i18n("Line\n\nDraw a straight line vertically, horizontally or at 45 deg. angles");
   what->add(drawtoolbar->getButton(ID_DRAW_LINE), str);
 
   str = i18n("Spray\n\nDraw scattered pixels in the current color");
   what->add(drawtoolbar->getButton(ID_DRAW_SPRAY), str);
 
-  str = i18n("Find\n\nThe color of the pixel clicked on will be the current drawcolor");
+  str = i18n("Find\n\nThe color of the pixel clicked on will be the current draw color");
   what->add(drawtoolbar->getButton(ID_DRAW_FIND), str);
 
   str = i18n("Erase\n\nErase pixels. Set the pixels to be transparent\n\n"
-             "(Tip: If you want to draw transparent with a different tool"
-             " then first click on \"Erase\" then on the tool you want to use)");
+             "(Tip: If you want to draw transparency with a different tool,"
+             " first click on \"Erase\" then on the tool you want to use)");
   what->add(drawtoolbar->getButton(ID_DRAW_ERASE), str);
 
   kdDebug() << "setupWhatsThis - done" << endl;
