@@ -22,7 +22,7 @@
 #define __KICONEDIT_H__
 
 #include <qdir.h>
-#include <qprinter.h>
+#include <kprinter.h>
 #include <qwidget.h>
 #include <qpixmap.h>
 #include <qfileinfo.h> 
@@ -206,7 +206,7 @@ protected:
   KIconEditProperties *kiprops;
   QWhatsThis *what;
   QImage img;
-  QPrinter *printer;
+  KPrinter *printer;
 };
 
 #endif //__KICONEDIT_H__
