@@ -189,7 +189,7 @@ void KIconEdit::slotPrint()
     file->setItemEnabled(ID_FILE_PRINT, false);
     toolbar->setItemEnabled(ID_FILE_PRINT, false);
 
-    if ( QPrintDialog::getPrinterSetup(printer) )
+    if ( printer->setup(this) )
     {
         int margin = 10, yPos = 0;
         printer->setCreator("KDE Icon Editor");
