@@ -25,9 +25,11 @@
 #include <qframe.h>
 #include <qpixmap.h>
 #include <qlabel.h>
-#include <qtablevw.h>
-#include <qpopmenu.h>
+#include <qtableview.h>
+#include <qpopupmenu.h>
+
 #include <kapp.h>
+
 #include "kiconcolors.h"
 
 class Preview : public QTableView
