@@ -24,6 +24,7 @@
 #include <klocale.h>
 #include <kglobal.h>
 #include <kiconloader.h>
+#include <kdebug.h>
 
 #include "knew.h"
 
@@ -74,11 +75,11 @@ KIconTemplateContainer::KIconTemplateContainer() : QObject()
 {
   QString path;
   instances++;
-  debug("KIconTemplateContainer: instances %d", instances);
+  kdDebug() << "KIconTemplateContainer: instances " << instances << endl;
   if(templatelist)
     return;
 
-  debug("KIconTemplateContainer: Creating templates");
+  kdDebug() << "KIconTemplateContainer: Creating templates" << endl;
 
   templatelist = new QList<KIconTemplate>;
   templatelist->setAutoDelete(true);
@@ -92,7 +93,7 @@ KIconTemplateContainer::KIconTemplateContainer() : QObject()
     KIconTemplate *it = new KIconTemplate;
     it->path = k->readEntry(names.at(i));
     it->title = names.at(i);
-    //debug("Template: %s\n%s", names.at(i), path.data());
+    //kdDebug() << "Template: " << names.at(i) << "\n" << path.data() << endl;
     templatelist->append(it);
   }
 
@@ -105,13 +106,13 @@ KIconTemplateContainer::KIconTemplateContainer() : QObject()
 KIconTemplateContainer::~KIconTemplateContainer()
 {
   instances--;
-  debug("KIconTemplateContainer: instances %d", instances);
+  kdDebug() << "KIconTemplateContainer: instances " << instances << endl;
   if(instances == 0)
   {
-    debug("KIconTemplateContainer: Deleting templates");
+    kdDebug() << "KIconTemplateContainer: Deleting templates" << endl;
     templatelist->clear();
     delete templatelist;
-    debug("KIconTemplateContainer: Deleted templates");
+    kdDebug() << "KIconTemplateContainer: Deleted templates" << endl;
   }
 }
 
@@ -124,10 +125,10 @@ QList<KIconTemplate> *KIconTemplateContainer::getTemplates()
 KIconListBoxItem::KIconListBoxItem( KIconTemplate *t )
    : QListBoxItem()
 {
-  //debug("KIconListBoxItem - %s, %s", t->path.data(), t->title.data());
+  //kdDebug() << "KIconListBoxItem - " << t->path.data() << ", " << t->title.data() << endl;
   icontemplate = t;
-  pm.load(t->path.data());
-  setText( t->title.data() );
+  pm.load(t->path);
+  setText( t->title );
 }
 
 void KIconListBoxItem::paint( QPainter *p )    
@@ -183,7 +184,7 @@ NewSelect::~NewSelect()
 
 void NewSelect::buttonClicked(int id)
 {
-  debug("Button: %d", id);
+  kdDebug() << "Button: " << id << endl;
 
   emit iconopenstyle(id);
 }
@@ -239,6 +240,9 @@ KNewIcon::KNewIcon( QWidget* parent )
   connect( select, SIGNAL( iconopenstyle( int ) ), SLOT( iconOpenStyle( int ) ) );
 
   scratch = new KResizeWidget( this, 0, QSize( 32, 32 ) );
+  // this doesn't accept default valid size, besides spin buttons won't allow 
+  // an invalid size to be set by the user - forces user to change valid default 
+  // size to create the new icon object - 
   connect( scratch, SIGNAL( validSize( bool ) ), SLOT( checkPage( bool ) ) );
   
   templ = new NewFromTemplate(this);
@@ -296,18 +300,34 @@ void KNewIcon::iconOpenStyle(int style)
 
 void KNewIcon::checkPage(int p)
 {
+
+if(openstyle == Blank)
+    finishButton()->setEnabled(true);
+else if(p == 0)
+    finishButton()->setEnabled(false);
+else
+    templ->checkSelection(0);
+
+/*
   if(p == 0)
     finishButton()->setEnabled(false);
   else if(openstyle == Blank)
     scratch->checkValue(0);
   else
     templ->checkSelection(0);
+*/
 }
 
-void KNewIcon::checkPage(bool ok)
+void KNewIcon::checkPage(bool /* ok */)
 {
-  if(ok && openstyle == Blank)
+  if(/* ok && */ openstyle == Blank)
     finishButton()->setEnabled(true);
   else
     finishButton()->setEnabled(false);
 }
+#include "knew.moc"
+
+
+
+
+
