@@ -21,6 +21,7 @@
 
 #include <kimageio.h>
 #include <klocale.h>
+#include <kdebug.h>
 
 #include "utils.h"
 #include "config.h"
@@ -34,7 +35,7 @@ void setupImageHandlers()
 
   KImageIO::registerFormats();
 
-  debug("Initializing formats");
+  kdDebug() << "Initializing formats" << endl;
   formats = new imageFormats;
   CHECK_PTR(formats);
   formats->setAutoDelete(true);
@@ -43,6 +44,7 @@ void setupImageHandlers()
   formats->append(new imageFormat("JFIF", "JPEG", "jpg"));
 #endif
   formats->append(new imageFormat("XPM", "XPM",  "xpm"));
+  formats->append(new imageFormat("ICO", "Icon File",  "ico"));
 /*
 #ifdef HAVE_LIBJPEG
   QImageIO::defineIOHandler("JFIF","^\377\330\377\340", 0, read_jpeg_jfif, NULL);
@@ -53,24 +55,24 @@ void setupImageHandlers()
 // Simple copy operation on local files (isn't there something like this in the libs?)
 bool copyFile(const QString &src, const QString &dest)
 {
-  QFile f_src(src.data());  
-  QFile f_dest(dest.data());  
+  QFile f_src(src);  
+  QFile f_dest(dest);  
   QFileInfo fi(f_src);
   uint src_size = fi.size();
-  debug("Size: %u", src_size);
+  kdDebug() << "Size: " << src_size << endl;
 
   if ( f_src.open(IO_ReadOnly) )
   {    // file opened successfully      
     if ( !f_dest.open(IO_WriteOnly) )
     {
-      debug("copyFile - There was an error opening destination file: %s", dest.data());
+      kdDebug() << "copyFile - There was an error opening destination file: " << dest << endl;
       f_src.close();
       return false;
     }
     char *data = new char[src_size];
     if(f_src.readBlock(data, src_size) == -1)
     {
-      debug("copyFile - There was an error reading source file: %s", src.data());
+      kdDebug() << "copyFile - There was an error reading source file: " << src << endl;
       f_src.close();
       f_dest.close();
       delete [] data;
@@ -78,7 +80,7 @@ bool copyFile(const QString &src, const QString &dest)
     }
     if(f_dest.writeBlock(data, src_size) == -1)
     {
-      debug("copyFile - There was an error writing to destination file: %s", dest.data());
+      kdDebug() << "copyFile - There was an error writing to destination file: " << dest << endl;
       f_src.close();
       f_dest.close();
       delete [] data;
@@ -90,19 +92,19 @@ bool copyFile(const QString &src, const QString &dest)
     delete [] data;
     return true;
   }
-  debug("copyFile - There was an error opening source file: %s", src.data());
+  kdDebug() << "copyFile - There was an error opening source file: " << src << endl;
   return false;
 }
 
 bool removeFile(const QString &file)
 {
-  if(file.length() > 0 && QFile::exists(file.data()))
+  if(file.length() > 0 && QFile::exists(file))
   {
     QDir d;
-    debug("Removing %s", file.data());
-    if(!d.remove(file.data()))
+    kdDebug() << "Removing " << file << endl;
+    if(!d.remove(file))
     {
-      debug("removeFile - There was an error removing the file: %s", file.data());
+      kdDebug() << "removeFile - There was an error removing the file: " << file << endl;
       return false;
     }
     return true;
@@ -123,10 +125,10 @@ uint kdeColor(uint color)
 
   for(uint i = 0; i < 42; i++)
   {
-    //debug("Color #%d %u", i, iconpalette[i]);
+    //kdDebug() << "Color #" << i << " " << iconpalette[i] << endl;
     if( (iconpalette[i]|OPAQUE_MASK) - c < (iconpalette[i]|OPAQUE_MASK) - color)
       c = iconpalette[i]|OPAQUE_MASK;
   }
-  //debug("%u -> %u", color, c);
+  //kdDebug() << color << " -> " << c << endl;
   return c;
 }
