@@ -1,19 +1,24 @@
-// $Id: areaselect.cpp,v 1.17 2000/06/05 11:04:59 hoelzer Exp $
+// $Id: areaselect.cpp,v 1.22 2000/12/11 19:53:27 jcaliff Exp $
 
-#include <kdebug.h>
 #include <stdio.h>
 #include <qcursor.h>
 #include <qpainter.h>
 #include <qstring.h>
 #include <qwmatrix.h>
+#include <qclipboard.h>
+
 #include <klocale.h>
-#include "areaselect.h"
+#include <kapp.h>
+#include <kdebug.h>
+#include <kmessagebox.h>
 #include <kiconloader.h>
 
+#include "areaselect.h"
+
 #define TIMER_INTERVALL 500
 
 
-AreaSelect::AreaSelect(const char *toolname) : Tool(toolname)
+AreaSelect::AreaSelect(const QString & toolname) : Tool(toolname)
 {
   drawing= FALSE;
   showedSF= false;
@@ -30,7 +35,7 @@ AreaSelect::~AreaSelect()
 void 
 AreaSelect::selection(bool b)
 {
-  debug("AreaSelect::selection %i",b);
+  kdDebug() << "AreaSelect::selection " << b << endl;
   if (!b) {
     disableSelection();
   }
@@ -48,13 +53,13 @@ AreaSelect::disableSelection()
 
 void AreaSelect::activating()
 {
-  kdDebug(3000) << "AreaSelect::activating() hook called\n" << endl;
+  kdDebug(4400) << "AreaSelect::activating() hook called\n" << endl;
   canvas->setCursor(crossCursor);
 }
 
 void AreaSelect::deactivating()
 {
-  kdDebug(3000) << "AreaSelect::deactivating() hook called\n" << endl;
+  kdDebug(4400) << "AreaSelect::deactivating() hook called\n" << endl;
   // erase old selection frame
   disableSelection();
   canvas->clearSelection();
@@ -68,11 +73,11 @@ AreaSelect::timerEvent(QTimerEvent *)
 
 void AreaSelect::mousePressEvent(QMouseEvent *e)
 {
-  kdDebug(3000) << "AreaSelect::mousePressEvent() handler called\n" << endl;
+  kdDebug(4400) << "AreaSelect::mousePressEvent() handler called\n" << endl;
   
   if (isActive() && (e->button() == LeftButton)) {
     if (drawing) {
-      kdWarning(3000) << "AreaSelect: Warning Left Button press received when pressed\n" << endl;
+      kdWarning(4400) << "AreaSelect: Warning Left Button press received when pressed\n" << endl;
     }
     else {
       // erase old selection frame
@@ -86,7 +91,7 @@ void AreaSelect::mousePressEvent(QMouseEvent *e)
     } 
   }
   if (!isActive()) {
-    kdWarning(3000) << "AreaSelect: Warning event received when inactive (ignoring)\n" << endl;
+    kdWarning(4400) << "AreaSelect: Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
@@ -119,7 +124,7 @@ void AreaSelect::mouseMoveEvent(QMouseEvent *e)
     }
   }
   else {
-kdWarning(3000) << "Warning event received when inactive (ignoring)\n" << endl;
+kdWarning(4400) << "Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
@@ -129,7 +134,7 @@ void AreaSelect::mouseReleaseEvent(QMouseEvent *e)
   QPainter paint;
   QWMatrix m;
 
-kdDebug(3000) << "AreaSelect::mouseReleaseEvent() handler called\n" << endl;
+kdDebug(4400) << "AreaSelect::mouseReleaseEvent() handler called\n" << endl;
 
   if (isActive() && (e->button() == LeftButton)) {
     x= (e->pos()).x();
@@ -158,7 +163,7 @@ kdDebug(3000) << "AreaSelect::mouseReleaseEvent() handler called\n" << endl;
     showedSF= false;
   }
   else {
-kdWarning(3000) << "Warning event received when inactive (ignoring)\n" << endl;
+kdWarning(4400) << "Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
@@ -180,4 +185,8 @@ AreaSelect::drawFrame()
   showedSF = !showedSF;
 }
 
+
 #include "areaselect.moc"
+
+#undef TIMER_INTERVALL /* for --enable-final */
+
