@@ -7,15 +7,16 @@
 paletteDialog::paletteDialog(QPixmap *p, QWidget *parent, const char *name)
   : QDialog(parent, name, TRUE)
 {
-  QPushButton *dismiss;
-  pal= new paletteWidget(p, this);
+  resize(340, 280);  
 
-  resize(340, 280);
-  dismiss = new QPushButton( i18n("Dismiss"), this );
-  dismiss->setAutoResize(TRUE);
+  pal= new paletteWidget(p, this);
   pal->move(10, 10);
   pal->resize(320, 240);
+
+  QPushButton *dismiss = new QPushButton( i18n("Dismiss"), this );
+  dismiss->setAutoResize(TRUE);
   dismiss->move(140, 250);
+
   connect( dismiss, SIGNAL(clicked()), SLOT(accept()) );
   connect( pal, SIGNAL(colourSelected(int)), pal, SLOT(editColour(int)) );
 }
