@@ -10,7 +10,7 @@ class Roundangle : public Tool
 {
   Q_OBJECT
 public:
-  Roundangle(const char *toolname);
+  Roundangle(const QString & toolname);
   void mousePressEvent(QMouseEvent *e);
   void mouseMoveEvent(QMouseEvent *e);
   void mouseReleaseEvent(QMouseEvent *e);
