@@ -11,10 +11,11 @@ typedef QStack<int> LineStack;
 
 class Text : public Tool
 {
-Q_OBJECT
+  Q_OBJECT
+
 public:
-Text();
-Text(const char *toolname);
+  Text();
+  Text(const QString & toolname);
 
   void mousePressEvent(QMouseEvent *);
   //  void mouseMoveEvent(QMouseEvent *e);
