@@ -18,12 +18,13 @@
 */
 
 #ifndef __kview_asyncio_h__
-#define __kview_asyncio_h__ "$Id: kview_asyncio.h,v 1.3 2001/02/07 20:18:46 deller Exp $"
+#define __kview_asyncio_h__ "$Id: kview_asyncio.h,v 1.3.4.1 2001/08/26 05:53:41 neil Exp $"
 
 #include <qasyncio.h>
 #include <qbuffer.h>
 
 class KVImageHolder;
+class KTempFile;
 namespace KIO { class Job; }
 
 class KIOImageSource : public QDataSource
@@ -54,7 +55,7 @@ class KIOImageLoader : QObject
 {
   Q_OBJECT
 public:
-  KIOImageLoader( KIO::Job *job, KVImageHolder *label );
+  KIOImageLoader( KIO::Job *job, KVImageHolder *label, KTempFile *temp = 0 );
 
 private slots:
   void slotData( KIO::Job * job , const QByteArray &data );
@@ -66,6 +67,7 @@ private:
   int m_iBuffPos;
   QBuffer *m_pBuffer;
   KVImageHolder *m_pLabel;
+  KTempFile *m_TempFile;
 };
 
 #endif
